@@ -1,6 +1,6 @@
 /*
  * XML LDAP client
- * $Id: xdap.c,v 1.5 2002/10/14 09:44:05 dsandras Exp $
+ * $Id: xdap.c,v 1.6 2002/10/30 12:08:15 dsandras Exp $
  * Copyright 2001 paul666@mailandnews.com
  * Licensed under version 2 or later of the GNU GPL
  */
@@ -629,7 +629,6 @@ doldapop (LDAP * ldap, xmlDocPtr xp, int sync, xmlNodePtr node, int optype,
 static int
 addattr (LDAPMod ** attrs, int *nattrs, char *name, char *val, int modval)
 {
-  gchar *gval = NULL;
   int j, k = 0;
 
   /* if attribute already exists */
@@ -656,10 +655,8 @@ addattr (LDAPMod ** attrs, int *nattrs, char *name, char *val, int modval)
   if (k >= MAXOPS)
     return PFTOOMANYOPS;
 	
-  gval = g_convert (val, strlen(val), "ISO-8859-1", "UTF-8", 0, 0, 0);
-  attrs[j]->mod_values[k] = (char *) xmlStrdup (BAD_CAST gval);
+  attrs[j]->mod_values[k] = (char *) xmlStrdup (BAD_CAST val);
   attrs[j]->mod_values[++k] = 0;
-  g_free (gval);
 
   return 0;
 }
